flexwidget-shiny: Shiny bindings for flexwidget

Description Usage Arguments Details

Description

Output and render functions for using flexwidget within Shiny applications and interactive Rmd documents.

Usage

1
2
3
flexwidgetOutput(outputId, width = "100%", height = "400px")

renderflexwidget(expr, env = parent.frame(), quoted = FALSE)

Arguments

outputId

output variable to read from

width, height

Must be a valid CSS unit (like '100%', '400px', 'auto') or a number, which will be coerced to a string and have 'px' appended.

expr

An expression that generates a flexwidget

env

The environment in which to evaluate expr.

quoted

Is expr a quoted expression (with quote())? This is useful if you want to save an expression in a variable.

Details

If using CDN for dependencies, you can add 'flexwidget_src' call into the UI. If accepting input that affects the javascript being passed to the widget, use caution as a user could inject something malicious. It is probably best to only have the data input to the widget change from user input.


AliciaSchep/flexwidget documentation built on May 7, 2019, 8:19 a.m.