Description Usage Arguments Details
Output and render functions for using flexwidget within Shiny applications and interactive Rmd documents.
1 2 3 | flexwidgetOutput(outputId, width = "100%", height = "400px")
renderflexwidget(expr, env = parent.frame(), quoted = FALSE)
|
outputId |
output variable to read from |
width, height |
Must be a valid CSS unit (like |
expr |
An expression that generates a flexwidget |
env |
The environment in which to evaluate |
quoted |
Is |
If using CDN for dependencies, you can add 'flexwidget_src' call into the UI. If accepting input that affects the javascript being passed to the widget, use caution as a user could inject something malicious. It is probably best to only have the data input to the widget change from user input.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.